/*
    Copyright 2005-2008 EPOS-Project
                        (FZ Dresden-Rossendorf & MLU Halle-Wittenberg)
                        Arnold Krille <arnold@arnoldarts.de>

    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; version 3 of the License.

    This library is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; see the files lgpl-3.0.txt and
    gpl-3.0.txt. If not, see <http://www.gnu.org/licenses/>.

*/

#include "cachingguiserver.h"

#include <time.h>

#include <QtCore/QDebug>

using namespace NSCore;

CachingGuiServer::CachingGuiServer( GuiServer_Interface* gui ) : _gui( gui ) {
}

void CachingGuiServer::message( const QString& title, const QString& text ) const {
	if ( time( 0 ) - _msg_cache.last > 10
		|| _msg_cache.title != title
		|| _msg_cache.text != text
	) {
		_gui->message( title, text );
		_msg_cache.title = title;
		_msg_cache.text = text;
		_msg_cache.last = time( 0 );
	}
}
bool CachingGuiServer::messageYesNo( const QString& title, const QString& text ) const {
	if ( abs( time( 0 ) - _msgOkCancel_cache.last ) > 10
		|| _msgOkCancel_cache.title != title
		|| _msgOkCancel_cache.text != text
	) {
		_msgOkCancel_cache.ret = _gui->messageYesNo( title, text );
		_msgOkCancel_cache.title = title;
		_msgOkCancel_cache.text = text;
		_msgOkCancel_cache.last = time( 0 );
	}
	return _msgOkCancel_cache.ret;
}
bool CachingGuiServer::messageOkCancel( const QString& title, const QString& text ) const {
	if ( abs( time( 0 ) - _msgOkCancel_cache.last ) > 10
		|| _msgOkCancel_cache.title != title
		|| _msgOkCancel_cache.text != text
	) {
		_msgOkCancel_cache.ret = _gui->messageOkCancel( title, text );
		_msgOkCancel_cache.title = title;
		_msgOkCancel_cache.text = text;
		_msgOkCancel_cache.last = time( 0 );
	}
	return _msgOkCancel_cache.ret;
}
double CachingGuiServer::getDouble( const QString& title, const QString& text, double value, double min, double max ) const {
	if ( abs( time( 0 ) - _msgOkCancel_cache.last ) > 10
		|| _getDouble_cache.title != title
		|| _getDouble_cache.text != text
		|| _getDouble_cache.value != value
		|| _getDouble_cache.min != min
		|| _getDouble_cache.max != max
	) {
		_getDouble_cache.ret = _gui->getDouble( title, text, value, min, max );
		_getDouble_cache.title = title;
		_getDouble_cache.text = text;
		_getDouble_cache.value = value;
		_getDouble_cache.min = min;
		_getDouble_cache.max = max;
		_getDouble_cache.last = time( 0 );
	}
	return _getDouble_cache.ret;
}
int CachingGuiServer::getInt( const QString& title, const QString& text, int value, int min, int max ) const {
	if ( abs( time( 0 ) - _msgOkCancel_cache.last ) > 10
		|| _getInt_cache.title != title
		|| _getInt_cache.text != text
		|| _getInt_cache.value != value
		|| _getInt_cache.min != min
		|| _getInt_cache.max != max
	) {
		_getInt_cache.ret = _gui->getInt( title, text, value, min, max );
		_getInt_cache.title = title;
		_getInt_cache.text = text;
		_getInt_cache.value = value;
		_getInt_cache.min = min;
		_getInt_cache.max = max;
		_getInt_cache.last = time( 0 );
	}
	return _getInt_cache.ret;
}
QString CachingGuiServer::getString( const QString& title, const QString& text, const QString& initvalue ) const {
	if ( abs( time( 0 ) - _msgOkCancel_cache.last ) > 10
		|| _getString_cache.title != title
		|| _getString_cache.text != text
		|| _getString_cache.value != initvalue
	) {
		_getString_cache.ret = _gui->getString( title, text, initvalue );
		_getString_cache.title = title;
		_getString_cache.text = text;
		_getString_cache.value = initvalue;
		_getString_cache.last = time( 0 );
	}
	return _getString_cache.ret;
}
QString CachingGuiServer::getItem( const QString& title, const QString& text, const QStringList& list ) const {
	if ( abs( time( 0 ) - _msgOkCancel_cache.last ) > 10
		|| _getItemStringList_cache.title != title
		|| _getItemStringList_cache.text != text
		|| _getItemStringList_cache.list != list
	) {
		_getItemStringList_cache.ret = _gui->getItem( title, text, list );
		_getItemStringList_cache.title = title;
		_getItemStringList_cache.text = text;
		_getItemStringList_cache.list = list;
		_getItemStringList_cache.last = time( 0 );
	}
	return _getItemStringList_cache.ret;
}
QString CachingGuiServer::getItem( const QString& title, const QString& text, const QList<ListItem> list ) const {
	if ( abs( time( 0 ) - _getItem_cache.last ) > 10
		|| _getItem_cache.title != title
		|| _getItem_cache.text != text
		|| _getItem_cache.list != list
	) {
		_getItem_cache.ret = _gui->getItem( title, text, list );
		_getItem_cache.title = title;
		_getItem_cache.text = text;
		_getItem_cache.list = list;
		_getItem_cache.last = time( 0 );
	}
	return _getItem_cache.ret;
}
QString CachingGuiServer::getFileName( const QString& title, const QString& dir, const QString& filter, const FileType& type ) {
	if ( abs( time( 0 ) - _msgOkCancel_cache.last ) > 10
		|| _getFileName_cache.title != title
		|| _getFileName_cache.dir != dir
		|| _getFileName_cache.filter != filter
		|| _getFileName_cache.type != type
	) {
		_getFileName_cache.ret = _gui->getFileName( title, dir, filter, type );
		_getFileName_cache.title = title;
		_getFileName_cache.dir = dir;
		_getFileName_cache.filter = filter;
		_getFileName_cache.type = type;
		_getFileName_cache.last = time( 0 );
	}
	return _getFileName_cache.ret;
}

