/*
    Copyright 2005-2008 EPOS-Project
                        (FZ Dresden-Rossendorf & MLU Halle-Wittenberg)
                        Arnold Krille <arnold@arnoldarts.de>

    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; version 3 of the License.

    This library is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; see the files lgpl-3.0.txt and
    gpl-3.0.txt. If not, see <http://www.gnu.org/licenses/>.

*/

#include "qtreeitem.h"
#include "qtreeitem.moc"

namespace NSCore {

	void QTreeItem::setObjectName( const QString& name ) {
		//qDebug() << "QTreeItem::setObjectName(" << name << ")";
		QString n = name;
		QTreeItem* p = dynamic_cast<QTreeItem*>( parent() );
		if ( p ) {
			QStringList list = p->childlist();
			int i = 0;
			while ( list.contains( n ) ) {
				qDebug() << "QTreeItem::setObjectName(" << name << ") already a child with name '" << n << "' existing.";
				n = QString( "%1-%2" ).arg( name ).arg( i );
				i++;
			}
		}
		QObject::setObjectName( n );
	}

	QVariant QTreeItem::guiIdentifier( int role ) const {
		switch ( role ) {
			case Qt::DisplayRole: {
				QString tmp = objectName();
				if ( tmp=="" )
					tmp = QString( "QTreeItem this=%1" ).arg( qptrdiff( this ) );
				return tmp; }
				break;
			case Qt::ToolTipRole:
				return _tooltip;
				break;
			default:
				return QVariant();
		}
	}

	bool QTreeItem::addChild( QTreeItem* item ) {
		if ( ! childobjects().contains( item ) )
			_morechilds.append( item );

		if ( childobjects().contains( item ) ) {
			emit newChildAdded( item );
			for ( std::list<PointerProtection_Base*>::iterator it = _pointers.begin(); it != _pointers.end(); ++it ) {
				QTreeItemPointer* tmp = dynamic_cast<QTreeItemPointer*>( *it );
				if ( tmp != 0 )
					tmp->newChildAdded( item );
			}
			return true;
		}

		qWarning() << "QTreeItem::addChild(" << item << ") returning false!";
		return false;
	}

	bool QTreeItem::saveToXmlNeeded() {
		bool save = needsToSaveToXml();
		foreach( QTreeItem* item, childobjects<QTreeItem>() )
			save |= item->needsToSaveToXml();
		return save;
	}
	QDomNode QTreeItem::toXml( QDomDocument doc ) {
		if ( ! saveToXmlNeeded() ) {
			qDebug() << "QTreeItem::toXml() decided not to save" << this;
			return QDomNode();
		}
		QDomNode node = saveToXML( doc );
		if ( !node.isNull() )
			foreach( QTreeItem* item, childobjects<NSCore::QTreeItem>() )
				node.appendChild( item->toXml( doc ) );
		return node;
	}
	bool QTreeItem::fromXml( QDomNode node ) {
		//qDebug() << "QTreeItem::fromXml() me =" << objectName();
		if ( QThread::currentThread() != thread() ) {
			//qWarning( "QTreeItem::fromXml(...) Not running in my own thread!" );
			_xmltoparse.append( node );
			QTimer::singleShot( 0, this, SLOT( workOnXmlCache() ) );
			while ( ! _xmltoparse.isEmpty() ) {
				QCoreApplication::processEvents();
			}
			return _xmlcachereturn;
		} else {
			if ( restoreFromXML( node ) && createFromXML( node ) ) {
				QDomNodeList childnodes = node.childNodes();
				QStringList childs = childlist<QTreeItem>();
				//qDebug() << "QTreeItem::fromXml() searching for xml-nodes for childs" << childs;
				for ( int i=0; i<childnodes.size(); ++i ) {
					foreach( QString tmp, childs ) {
						if ( child( tmp )->fromXml( childnodes.at( i ) ) )
							childs.removeAll( tmp );
					}
				}
				return true;
			}
		}
		return false;
	}
	void QTreeItem::workOnXmlCache() {
		while ( ! _xmltoparse.isEmpty() ) {
			_xmlcachereturn = fromXml( _xmltoparse.first() );
			_xmltoparse.takeFirst();
		}
	}

	QTreeItemPointer::QTreeItemPointer( QTreeItem* object, QTreeItem* parent )
		: QTreeItem( parent )
		, Pointer_template<QTreeItem>( object )
	{
		setObjectName( object->objectName() );
	}

};

