/*
    Copyright 2005-2008 EPOS-Project
                        (FZ Dresden-Rossendorf & MLU Halle-Wittenberg)
                        Arnold Krille <arnold@arnoldarts.de>

    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; version 3 of the License.

    This library is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; see the files lgpl-3.0.txt and
    gpl-3.0.txt. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef XYSPECVIEW_H
#define XYSPECVIEW_H

#include <QtGui/QAbstractItemView>

class XYSpecView_Private;

class XYSpecView : public QAbstractItemView
{
	Q_OBJECT
	public:
		XYSpecView( QWidget* =0 );
		~XYSpecView();

		QRect visualRect( const QModelIndex& ) const;
		void scrollTo( const QModelIndex&, ScrollHint =EnsureVisible );
		QModelIndex indexAt( const QPoint& ) const;

		void setModel( QAbstractItemModel* );

	protected:
		void paintEvent( QPaintEvent* );
		void contextMenuEvent( QContextMenuEvent* );

	private:
		/// private d-pointer
		XYSpecView_Private* d;

		QModelIndex moveCursor( QAbstractItemView::CursorAction, Qt::KeyboardModifiers );

		int horizontalOffset() const;
		int verticalOffset() const;

		bool isIndexHidden( const QModelIndex& ) const;

		void setSelection( const QRect&, QItemSelectionModel::SelectionFlags );

		QRegion visualRegionForSelection( const QItemSelection& ) const;

	protected slots:
		void dataChanged( const QModelIndex&, const QModelIndex& );

		void setLogarithmicZ( bool );

		void setColor( QAction* );

};

#endif // XYSPECVIEW_H

