/*
    Copyright 2005-2008 EPOS-Project
                        (FZ Dresden-Rossendorf & MLU Halle-Wittenberg)
                        Arnold Krille <arnold@arnoldarts.de>

    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
    published by the Free Software Foundation; version 3 of the License.

    This library is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; see the files lgpl-3.0.txt and
    gpl-3.0.txt. If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef MODIFIERS_H
#define MODIFIERS_H

#include "plugins_interface.h"

class AbsModifier : public NSEvaluation::Modifier
{
	public:
		AbsModifier( NSCore::QTreeItem* );

		void modify( NSCore::AcqisitionDataSet&, int );

		QString type() const { return "AbsModifier"; }
};

class NormalizeModifier : public NSEvaluation::Modifier
{
	public:
		NormalizeModifier( NSCore::QTreeItem* );

		void modify( NSCore::AcqisitionDataSet&, int );

		QString type() const { return "NormalizeModifier"; }
};

void simpleAverager( int neighbors, int samplesize, const double* in, double *out );
void simpleAveragerV2( int neighbors, int samplesize, const double* in, double *out );
void weightedAverager( int neighbors, int samplesize, const double* in, double *out, double* weights =0 );

class FloatingAverageModifier : public NSEvaluation::Modifier
{
	public:
		FloatingAverageModifier( NSCore::QTreeItem* );

		void modify( NSCore::AcqisitionDataSet&, int );

		QString type() const { return "FloatingAverageModifier"; }
};

class IntegrateModifier : public NSEvaluation::Modifier
{
	public:
		IntegrateModifier( NSCore::QTreeItem* );

		void modify( NSCore::AcqisitionDataSet&, int );

		QString type() const { return "IntegrateModifier"; }
};

class InterpolatedMinimumAnalyzer;

class PulseIntegrate : public NSEvaluation::Modifier
{
	public:
		PulseIntegrate( NSCore::QTreeItem* );
		void modify( NSCore::AcqisitionDataSet&, int );
		QString type() const { return "PulseIntegrate"; }
};

class SignedIntegrate : public NSEvaluation::Modifier
{
	public:
		SignedIntegrate( NSCore::QTreeItem* );
		void modify( NSCore::AcqisitionDataSet&, int );
		QString type() const { return "SignedIntegrate"; }
};

class Differentiate : public NSEvaluation::Modifier
{
	public:
		Differentiate( NSCore::QTreeItem* );
		void modify( NSCore::AcqisitionDataSet&, int );
		QString type() const { return "Differentiate"; }
};

class CrossCorrelation : public NSEvaluation::Modifier
{
	public:
		CrossCorrelation( NSCore::QTreeItem* );
		void modify( NSCore::AcqisitionDataSet&, int );
		QString type() const { return "CrossCorrelation"; }
};

#endif // MODIFIERS_H

